@@ -110,7 +110,6 @@ OC.L10N.register(
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera se eliminan después de {numDays} día","Los elementos en la papelera se eliminan después de {numDays} días","Los elementos en la papelera se eliminan después de {numDays} días"],
     "Could not update calendar order." : "No se pudo actualizar el orden del calendario.",
     "Deck" : "Deck",
-    "Hidden" : "Oculto",
     "Internal link" : "Enlace interno",
     "A private link that can be used with external clients" : "Un enlace privado que puede usarse con clientes externos",
     "Copy internal link" : "Copiar enlace interno",
@@ -132,12 +131,10 @@ OC.L10N.register(
     "Deleting share link …" : "Eliminando enlace compartido …",
     "An error occurred while unsharing the calendar." : "Ocurrió un error al dejar de compartir el calendario.",
     "An error occurred, unable to change the permission of the share." : "Ocurrió un error, no se pudo cambiar el permiso de la compartición.",
-    "can edit" : "puede editar",
     "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "No users or groups" : "Sin usuarios ni grupos",
     "Failed to save calendar name and color" : "Error al guardar el nombre y el color del calendario",
-    "Calendar name …" : "Nombre del calendario …",
     "Share calendar" : "Compartir calendario",
     "Unshare from me" : "Dejar de compartir conmigo",
     "Save" : "Guardar",
@@ -153,13 +150,13 @@ OC.L10N.register(
     "Invalid location selected" : "Ubicación seleccionada no válida",
     "Attachments folder successfully saved." : "Carpeta de adjuntos guardada correctamente.",
     "Error on saving attachments folder." : "Error al guardar la carpeta de adjuntos.",
-    "Default attachments location" : "Ubicación predeterminada para adjuntos",
+    "Attachments folder" : "Carpeta de archivos adjuntos",
     "{filename} could not be parsed" : "No se pudo analizar {filename}",
     "No valid files found, aborting import" : "No se encontraron archivos válidos, se cancela la importación",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó correctamente %n evento","Se importaron correctamente %n eventos","Se importaron correctamente %n eventos"],
     "Import partially failed. Imported {accepted} out of {total}." : "La importación falló parcialmente. Se importaron {accepted} de {total}.",
     "Automatic" : "Automático",
-    "Automatic ({detected})" : "Automático ({detected})",
+    "Automatic ({timezone})" : "({timezone}) automática",
     "New setting was not saved successfully." : "No se guardó correctamente la nueva configuración.",
     "Timezone" : "Zona horaria",
     "Navigation" : "Navegación",
@@ -182,19 +179,11 @@ OC.L10N.register(
     "or" : "o",
     "Calendar settings" : "Configuración del calendario",
     "No reminder" : "Sin recordatorio",
-    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
-    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
     "General" : "General",
-    "Personal availability settings" : "Configuración de disponibilidad personal",
-    "Copy primary CalDAV address" : "Copiar dirección CalDAV principal",
-    "Copy iOS/macOS CalDAV address" : "Copiar dirección CalDAV para iOS/macOS",
-    "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
-    "Show tasks in calendar" : "Mostrar tareas en el calendario",
-    "Show weekends" : "Mostrar fines de semana",
-    "Show week numbers" : "Mostrar número de semana",
+    "Appearance" : "Apariencia",
     "Editing" : "Edición",
     "Default reminder" : "Recordatorio predeterminado",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "Files" : "Archivo",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
@@ -238,6 +227,7 @@ OC.L10N.register(
     "Your email address" : "Tu dirección de correo electrónico",
     "Please share anything that will help prepare for our meeting" : "Por favor, comparte cualquier información que ayude a prepararnos para nuestra reunión",
     "Could not book the appointment. Please try again later or contact the organizer." : "No se pudo reservar la cita. Inténtalo de nuevo más tarde o contacta al organizador.",
+    "Back" : "Regresar",
     "Select conversation" : "Seleccionar conversación",
     "on" : "el",
     "at" : "a las",
@@ -298,8 +288,6 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
     "No attendees yet" : "Aún no hay asistentes",
-    "Successfully appended link to talk room to description." : "Enlace a la sala de Talk se agregó correctamente a la descripción.",
-    "Error creating Talk room" : "Error al crear la sala de Talk",
     "Attendees" : "Asistentes",
     "Remove group" : "Eliminar grupo",
     "Remove attendee" : "Eliminar asistente",
@@ -357,6 +345,7 @@ OC.L10N.register(
     "Public calendar does not exist" : "El calendario público no existe",
     "Maybe the share was deleted or has expired?" : "¿Tal vez la compartición fue eliminada o ha expirado?",
     "Maybe" : "Tal vez",
+    "None" : "Ninguno",
     "Create" : "Crear",
     "from {formattedDate}" : "desde {formattedDate}",
     "to {formattedDate}" : "hasta {formattedDate}",
@@ -478,7 +467,6 @@ OC.L10N.register(
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
     "Add a location" : "Agregar una ubicación",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
@@ -501,10 +489,27 @@ OC.L10N.register(
     "This is an event reminder." : "Esto es un recordatorio de evento.",
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
+    "Hidden" : "Oculto",
+    "can edit" : "puede editar",
+    "Calendar name …" : "Nombre del calendario …",
+    "Default attachments location" : "Ubicación predeterminada para adjuntos",
+    "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Resumen de accesos directos",
+    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
+    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
+    "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
+    "Show tasks in calendar" : "Mostrar tareas en el calendario",
     "Enable simplified editor" : "Habilitar editor simplificado",
     "Limit the number of events displayed in the monthly view" : "Limitar la cantidad de eventos mostrados en la vista mensual",
+    "Show weekends" : "Mostrar fines de semana",
+    "Show week numbers" : "Mostrar número de semana",
     "Time increments" : "Incrementos de tiempo",
-    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado"
+    "Copy primary CalDAV address" : "Copiar dirección CalDAV principal",
+    "Copy iOS/macOS CalDAV address" : "Copiar dirección CalDAV para iOS/macOS",
+    "Personal availability settings" : "Configuración de disponibilidad personal",
+    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
+    "Successfully appended link to talk room to description." : "Enlace a la sala de Talk se agregó correctamente a la descripción.",
+    "Error creating Talk room" : "Error al crear la sala de Talk",
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
