@@ -257,6 +257,7 @@ OC.L10N.register(
     "Public calendar does not exist" : "לוח השנה הציבורי אינו קיים",
     "Maybe the share was deleted or has expired?" : "אולי השיתוף נמחק או פג תוקפו?",
     "None" : "ללא",
+    "Create" : "יצירה",
     "from {formattedDate}" : "מ- {formattedDate}",
     "to {formattedDate}" : "אל {formattedDate}",
     "on {formattedDate}" : "בתאריך {formattedDate}",
@@ -379,7 +380,6 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
     "Successfully appended link to talk room to description." : "הקישור צורף ל\"חדר השיחות\" לתיאור בהצלחה.",
     "Error creating Talk room" : "שגיאה ביצירת \"חדר השיחות\"",
-    "The visibility of this event in shared calendars." : "הנראות של אירוע זה בלוחות שנה משותפים.",
-    "Keyboard shortcuts" : "קיצורי מקלדת"
+    "The visibility of this event in shared calendars." : "הנראות של אירוע זה בלוחות שנה משותפים."
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
